@@ -6,4 +6,4 @@ __email__                       = "matthew@webheroes.ca"
 __copyright__                   = "Copyright (c) 2013 Web Heroes Inc."
 __license__                     = "Dual License: GPLv3 (or later) and Commercial (see LICENSE)"
 
-__all__                         = ["address_book", "chats"]
+__all__                         = ["address_book", "chats", "utils"]
